# DRF Manipulation

It's really common to have fields like "inserted_at", "updated_at",
"created_at", "last_modification", "last_update", etc in tables. To avoid
repeatedly copy-past these fields, I made this package.

# Installation

```shell
pip install drf-manipulation
```

Or, if you want the latest version, you can directly install the package from
the source code:

```shell
pip install https://github.com/xanigo/drf-manipulation/archive/refs/heads/master.zip
```

Or using git:

```shell
pip install git+ssh://git@github.com/xanigo/drf-manipulation.git
```
